#!/bin/bash
#
#   USAGE:  buildGeant4.sh <gcc46|gcc47|e2|supcl|f1> <debug|opt|prof>

basequal=${1}
extras=${2}

pkgver=v4_9_6_p01
pkgdotver=9.6.1

if [ -z ${basequal} ]
then
    echo "ERROR: please specify the base qualifier"
    echo "USAGE: buildGeant4.sh <gcc46|gcc47|e2|supcl|f1> <debug|opt|prof>"
    exit 1
fi

bqual=`echo ${basequal} | sed 's/:/-/g'`
if [ "${extras}" = "debug" ]
then
    qual=${basequal}:debug
    qdir=${bqual}-debug
elif [ "${extras}" = "opt" ]
then
    qual=${basequal}:opt
    qdir=${bqual}-opt
elif [ "${extras}" = "prof" ]
then
    qual=${basequal}:prof
    qdir=${bqual}-prof
else
    echo "ERROR: please specify debug, opt, or prof"
    echo "USAGE: buildGeant4.sh <gcc46|gcc47|e2|supcl|f1> <debug|opt|prof>"
    exit 1
fi


source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
g4dir=${PRODUCTS}/geant4/${pkgver}/${flvr}-${qdir}

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

mkdir -p ${g4dir}
if [ ! -d ${g4dir} ]
then
   echo "ERROR: failed to create ${g4dir}"
   exit 1
fi

# declare and then build geant4
echo "Declaring geant4 ${pkgver} for flavor ${flvr}"
if [ ${OS} = "Darwin" ]
then
   ups declare geant4 ${pkgver} -r geant4/${pkgver} -2 -m geant4.table -q ${qual}
else 
   ups declare geant4 ${pkgver} -r geant4/${pkgver} -4 -m geant4.table -q ${qual}
fi

echo "calling ups build geant4 ${pkgver} -q ${qual}"

ups build geant4 ${pkgver} -q ${qual}

# this should not complain
echo "Finished building geant4 ${pkgver} ${flvr} -q ${qual}"
setup geant4 ${pkgver} -q ${qual}

if [ ! -d ${G4LIB} ]
then
   echo "ERROR: failed to create ${G4LIB}"
   echo "       Something is very wrong"
   exit 1
fi
echo "G4LIB is ${G4LIB}"

# remove build directory from prof and opt distributions
if [ "${extras}" = "opt" ]
then
  if [ -d ${g4dir}/build ]
  then
    rm -rf ${g4dir}/build
  fi
elif [ "${extras}" = "prof" ]
then
  if [ -d ${g4dir}/build ]
  then
    rm -rf ${g4dir}/build
  fi
fi


# need to fix paths:
# bin/geant4-config
# lib64/Geant4-9.5.2/Geant4*.cmake
# share/Geant4-9.5.2/geant4make/geant4make*sh

rm -f /tmp/g4fix.sh

echo "#!/bin/bash" > /tmp/g4fix.sh
##echo " set -x " >>  /tmp/g4fix.sh
echo "mv ${GEANT4_FQ_DIR}/bin/geant4-config ${GEANT4_FQ_DIR}/bin/geant4-config.bak" >> /tmp/g4fix.sh
echo "cat ${GEANT4_FQ_DIR}/bin/geant4-config.bak | sed 's%${CLHEP_BASE_DIR}%\${CLHEP_BASE_DIR}%'  | sed 's%${XERCESCROOT}%\${XERCESCROOT}%' > ${GEANT4_FQ_DIR}/bin/geant4-config" >> /tmp/g4fix.sh
echo "chmod +x  ${GEANT4_FQ_DIR}/bin/geant4-config" >> /tmp/g4fix.sh

cmakeConfig=`ls ${GEANT4_FQ_DIR}/lib64/Geant4-${pkgdotver}/Geant4*.cmake`
for file in ${cmakeConfig}
do
  echo "mv ${file} ${file}.bak" >> /tmp/g4fix.sh
  echo "cat ${file}.bak | sed 's%${CLHEP_BASE_DIR}%\$ENV{CLHEP_BASE_DIR}%'  | sed 's%${XERCESCROOT}%\$ENV{XERCESCROOT}%' > ${file}" >> /tmp/g4fix.sh
done

g4make=`ls ${GEANT4_FQ_DIR}/share/Geant4-${pkgdotver}/geant4make/geant4make*sh`
for file in ${g4make}
do
  echo "mv ${file} ${file}.bak" >> /tmp/g4fix.sh
  echo "cat ${file}.bak | sed 's%${CLHEP_BASE_DIR}%\${CLHEP_BASE_DIR}%'  | sed 's%${XERCESCROOT}%\${XERCESCROOT}%' > ${file}" >> /tmp/g4fix.sh
  echo "chmod +x  ${file}" >> /tmp/g4fix.sh
done

chmod +x /tmp/g4fix.sh
/tmp/g4fix.sh

exit 0
