#!/bin/bash
#
#  USAGE: tarGeant4.sh <qualifier> [source]
#  geant4 tarballs are a special case

if [ $# -lt 1 ]
then
   echo "USAGE:  `basename ${0}` <qualifier> [source]" 
   exit 1
fi

qual=${1}
type=${2}
package=geant4
pkgver=v4_9_6_p01
pkgdotver=`echo ${pkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
tmpdir=/local/fwdev/

if [ "${type}" = "source" ]
then
    set -x
    cd ${PRODUCTS}
    tar cjf ${tmpdir}${package}-${pkgdotver}-source.tar.bz2 \
       ${package}/${pkgver}/*.sh \
       ${package}/${pkgver}/ups \
       ${package}/${pkgver}/source
    set +x
    exit 0
fi

##qualdir=`echo ${qual} | tr ":" "-"`
qlist=`echo ${qual} | sed -e 's/:/ /g' | tr " " "\n"| sort |tr "\n" " "`
fullqual=`echo ${qlist} | tr " " "_"`

#directory order: mu-e2-prof, e2-debug, etc.
qualdir=
for q in $qlist
do
  if [ ${q} = "mu" ]
  then
    qualdir=${q}-
  fi
done
for q in $qlist
do
  if [ ${q} = "e2" ] || [ ${q} = "gcc46" ] || [ ${q} = "gcc47" ] || [ ${q} = "f1" ] || [ ${q} = "f2" ]
  then
    qualdir=${qualdir}${q}-
  fi
done
for q in $qlist
do
  if [ ${q} = "debug" ] || [ ${q} = "opt" ] || [ ${q} = "prof" ]
  then
    qualdir=${qualdir}${q}
  fi
done

##echo "debug: ${qual} -> ${qlist}"
##echo "debug: fullqual ${fullqual}"
##echo "debug: qualdir ${qualdir}"

source ${PRODUCTS}/setup
OS1=`uname`

if [ ${OS1} = "Darwin" ]
then
    flvr=`ups flavor -2`
    plat=`uname -m`
    OSnum=`uname -r | cut -f1 -d"."`
    macos=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep Mac | cut -d ' ' -f 4 | cut -d . -f 1,2`
    macos1=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep Mac | cut -d ' ' -f 4 | cut -d . -f 1`
    macos2=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep Mac | cut -d ' ' -f 4 | cut -d . -f 2`
    #OS=${OS1}${OSnum}
    OS=mac${macos1}${macos2}
else
    flvr=`ups flavor`
    plat=`uname -p`
    OSnum=`lsb_release -r | cut -f2 | cut -f1 -d"."`
    OS=${OS1}${OSnum}
    if [ `lsb_release -d | cut  -f3 -d" "` = "SLF" ]
    then
       OS=slf${OSnum}
    fi
   if [ `lsb_release -i | cut -f2` = "ScientificFermi" ]
   then
      OS=slf${OSnum}
   fi
    if [ `lsb_release -d | cut  -f4 -d" "` = "SLC" ]
    then
       OS=slc${OSnum}
    fi
    if [ `lsb_release -d | cut  -f4 -d" "` = "LTS" ]
    then
       OS=slf${OSnum}
    fi
fi

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi
tarname=${tmpdir}${package}-${pkgdotver}-${OS}-${plat}-${qualdir}.tar.bz2
fqdir=${flvr}-${qualdir}

echo "OK - building tarball for ${package} ${pkgver} ${flvr} ${qual}"

set -x

cd ${PRODUCTS}

tar cjf ${tarname} \
   ${package}/${pkgver}.version/${flvr}_${fullqual} \
   ${package}/${pkgver}/ups \
   ${package}/${pkgver}/source \
   ${package}/${pkgver}/${fqdir}

set +x

exit
